@@ -160,11 +160,7 @@ class Query(object):
 
         for filter_statement in self.filters:
 
-            print(isinstance(filter_statement.value, str))
-            print(isinstance(filter_statement.value, basestring))
-            print(type(filter_statement.value, str))
-
-            if isinstance(filter_statement.value, str):
+            if isinstance(filter_statement.value, basestring):
                 query_data += ' FILTER %s.%s %s "%s"' % (
                     self._get_collection_ident(filter_statement.collection),
                     filter_statement.attribute,
